@@ -1,7 +1,7 @@
 /*
  * fsarchiver: Filesystem Archiver
  *
- * Copyright (C) 2008-2010 Francois Dupoux.  All rights reserved.
+ * Copyright (C) 2008-2012 Francois Dupoux.  All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -29,16 +29,25 @@ int btrfs_check_support_for_features(u64 compat, u64 incompat, u64 ro_compat);
 int btrfs_get_reqmntopt(char *partition, struct s_strlist *reqopt, struct s_strlist *badopt);
 int btrfs_test(char *devname);
 
-// compat flags: official definition from linux-2.6.35/fs/btrfs/ctree.h
+// compat flags: official definition from linux-3.4/fs/btrfs/ctree.h
 #define BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF    (1ULL << 0)
-#define BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL   (2ULL << 0)
+#define BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL   (1ULL << 1)
+#define BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS     (1ULL << 2)
+#define BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO     (1ULL << 3)
+#define BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2   (1ULL << 4)
+#define BTRFS_FEATURE_INCOMPAT_BIG_METADATA     (1ULL << 5)
+
 
 // compat flags: btrfs features that this fsarchiver version supports
 #define FSA_BTRFS_FEATURE_COMPAT_SUPP           0ULL
 #define FSA_BTRFS_FEATURE_COMPAT_RO_SUPP        0ULL
 #define FSA_BTRFS_FEATURE_INCOMPAT_SUPP         \
         (BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF | \
-         BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL)
+         BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL | \
+         BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS | \
+         BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO | \
+         BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2 | \
+         BTRFS_FEATURE_INCOMPAT_BIG_METADATA)
 
 // disk layout definitions
 #define BTRFS_SUPER_MAGIC 0x9123683E
